@@ -1222,9 +1222,6 @@ const char *IcsGetErrorText(Ics_Error error)
         case IcsErr_EndOfStream:
             msg = "Unexpected end of stream";
             break;
-        case IcsErr_FailWriteLine:
-            msg = "Failed to write a line in .ics file";
-            break;
         case IcsErr_FCloseIcs:
             msg = "File close error on .ics file";
             break;
@@ -1256,8 +1253,8 @@ const char *IcsGetErrorText(Ics_Error error)
         case IcsErr_FWriteIds:
             msg = "File write error on .ids file";
             break;
-        case IcsErr_IllegalROI:
-            msg = "The given ROI extends outside the image";
+        case IcsErr_FailWriteLine:
+            msg = "Failed to write a line in .ics file";
             break;
         case IcsErr_IllIcsToken:
             msg = "Illegal ICS token detected";
@@ -1266,6 +1263,9 @@ const char *IcsGetErrorText(Ics_Error error)
             msg = "A function parameter has a value that is not legal or does "
                 "not match with a value previously given";
             break;
+        case IcsErr_IllegalROI:
+            msg = "The given ROI extends outside the image";
+            break;
         case IcsErr_LineOverflow:
             msg = "Line overflow in .ics file";
             break;
@@ -1275,9 +1275,6 @@ const char *IcsGetErrorText(Ics_Error error)
         case IcsErr_MissCat:
             msg = "Missing main category";
             break;
-        case IcsErr_MissingData:
-            msg = "There is no Data defined";
-            break;
         case IcsErr_MissLayoutSubCat:
             msg = "Missing layout subcategory";
             break;
@@ -1293,9 +1290,15 @@ const char *IcsGetErrorText(Ics_Error error)
         case IcsErr_MissSensorSubSubCat:
             msg = "Missing sensor subsubcategory";
             break;
+        case IcsErr_MissSensorSubSubCatIndex:
+            msg = "Missing sensor subsubcategory index";
+            break;
         case IcsErr_MissSubCat:
             msg = "Missing sub category";
             break;
+        case IcsErr_MissingData:
+            msg = "There is no Data defined";
+            break;
         case IcsErr_NoLayout:
             msg = "Layout parameters missing or not defined";
             break;
@@ -1308,12 +1311,12 @@ const char *IcsGetErrorText(Ics_Error error)
         case IcsErr_NotValidAction:
             msg = "The function won't work on the ICS given";
             break;
-        case IcsErr_TooManyChans:
-            msg = "Too many channels specified";
-            break;
         case IcsErr_TooManyDetectors:
             msg = "Too many detectors specified";
             break;
+        case IcsErr_TooManyChans:
+            msg = "Too many channels specified";
+            break;
         case IcsErr_TooManyDims:
             msg = "Data has too many dimensions";
             break;
